#!/usr/bin/perl

# Version 1.1
# Fixed bug in find where directories were chmod 644 - oops

# Version 1.0
# Original Release

# This is a contributed script.  Minimal testing has been done
# and it's possible that running it may damage your machine in
# some way.  Use at you own risk!
#
# That being said, this is a pretty simple script which "monitors"
# a directory to see if it has "changed" (as reported by stat's
# "mtime").  Once a change is detected, then you can kick off
# another program (i.e. friendly_links or a chmod script)
#
# Script to see when files get added to the DEC.  Then 
# I'll run the friendly_links scripts to update the
# mapped directory
# 
# Dave O

################################################################
# Things you will *need* to configure
################################################################


# This needs to be the full path to your friendly_links program
# vi newbies:  use arrows to put cursor over the first "/" and
# then type "C" (that's Capital 'C').  It will nuke everything
# to the right of the cursor and you'll have to re-type the
# whole line.  When you're done.  Hit [esc], and then ":wq".
# If you screw up, you can try a 'U' which will undo your change.
# If you want to bail out without writing the file, hit:
# [esc]:q!
#
# ORIGINAL LINE FOR YOUR REFERENCE [don't edit]
# $LINKS_PROGRAM = "/content/sw/friendly_links.pl";

# EDIT THIS ONE
$LINKS_PROGRAM = "/content/sw/friendly_links.pl -suv";

# This is the command line I chose to alter file permissions
# I actually don't think you'll need to change this.
# $CHANGE_PERMS = "/usr/bin/find /content/music/ripped -type f | xargs chmod 644";
$CHANGE_PERMS = "/usr/bin/find /content/music/ripped/ -type f -exec chmod 644 {} \\;";


################################################################
# Things which you *may* configure if you're a tinkerer
################################################################


# This is a log file which records when the script discovers a change

# I need to leave some "marker" files laying around in between runs
# to detect when a directory change has occurred.  
$STAT_TMPDIR = "/var/tmp";
$LOG_FILE = "$STAT_TMPDIR/MARKER.log";


################################################################
# You shoudn't need to change anything below this line.  Please
# know what you're doing if you do.  
################################################################


open (LOG, '>>', $LOG_FILE) || die ("Couldn't create $LOG_FILE");

# Directories to check

# /content/imported/slurp is where stuff is slurped to
# /content/music/ripped is where stuff is ripped  to
# /content/imported/tmp is where stuff is staged before it is slurped

	@directories = qw#
	/content/music/ripped
    /content/music/slurped
    /content/imported/tmp
	#;

	# Check each directory for changes
	foreach $fn (@directories)
	{
		print "Checking $fn for changes...\n";
		&check ($fn);
	} 

	if ($UPDATE_LINKS)
	{
		print "Updating links...  \n";
		system ($LINKS_PROGRAM);
		print "Changing permissions on ripped MP3s... \n ";
		system ($CHANGE_PERMS);
		print "done! \n";
	}

sub check # $fn
{

		$marker_file = $fn;

		$marker_file =~ s#/#_#g;
		$marker_file =~ s#^#/$STAT_TMPDIR/MARKER#;

		# print "$marker_file \n";

	if (!-f $marker_file)
	{
		# If the marker file doesn't exist, then creat it
		print "Couldn't find $marker_file, creating... \n";
		open (MARKER, '>', $marker_file) || die ("Couldn't create $marker_file");
		close (MARKER);
	}


	# check time stamp in marker_file
	open (MARKER, '<', $marker_file) 
	  || die ("Couldn't open marker file $marker_file \n");

	read (MARKER, $LASTM, -s MARKER);
	chop $LASTM;
	close (MARKER);
	

	# Check current mtime on directory
	$mtime = (stat($fn)) [9]; 

	print "	Last modified value is $LASTM \n";
	print "	Curr modified value is $mtime \n";

	if ($LASTM == $mtime)
	{
		print "	No change - exiting \n";
	}
	else
	{
		print "	$fn has Changed! - will run update script \n";
		$now_string = localtime;
		print LOG "Content changed in $fn at $now_string \n";

		# Set flag to update links
		$UPDATE_LINKS = 1;
	}

	# Write updated time to marker_file
	open (MARKER, '>', $marker_file) 
	  || die ("Couldn't open marker file $marker_file \n");

	# print "	writing $mtime \n";
	print MARKER "$mtime\n";


# ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime($mtime);
# 	$mon++;
# 	$year += 1900;
# 	printf "%02d/%02d/%4d %02d:%02d:%02d \n", $mon,$mday,$year,$hour,$min,$sec;
}

